@@ -613,6 +613,7 @@ class Camera(BaseCamera):
     hasAudioDetector: bool
     hasMotionDetector: bool
     hasObjectDetector: bool
+    extendedMotionDetector: bool
     hasPtz: bool
     hasPrebuffer: bool
     sources: list[CameraInput]
@@ -670,6 +671,7 @@ CameraPublicProperties = Literal[
     "hasAudioDetector",
     "hasMotionDetector",
     "hasObjectDetector",
+    "extendedMotionDetector",
     "hasPrebuffer",
     "hasPtz",
     "sources",
@@ -710,6 +712,8 @@ class CameraDevice(Protocol):
     @property
     def has_motion_detector(self) -> bool: ...
     @property
+    def extended_motion_detector(self) -> bool: ...
+    @property
     def has_audio_detector(self) -> bool: ...
     @property
     def has_object_detector(self) -> bool: ...
